#
# spec file for package nodejs4
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

###########################################################
#
#   WARNING! WARNING! WARNING! WARNING! WARNING! WARNING!
#
# This spec file is generated from a template hosted at
# https://github.com/AdamMajer/nodejs-packaging
#
###########################################################

Name:           nodejs4
Version:        4.9.1
Release:        17.1

%define node_version_number 4

%if %node_version_number >= 10
%define openssl_req_ver 1.1.0
%else # node8 or older
%define openssl_req_ver 1.0.2
%endif

%if 0%{?suse_version} == 1110
%define _libexecdir %{_exec_prefix}/lib
%endif

# Only Leap 42.2+, SLE 12 SP2+ and Tumbleweed have OpenSSL 1.0.2.
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
%bcond_with    intree_openssl
%else
%bcond_without intree_openssl
%endif

%if 0
%bcond_with    intree_cares
%else
%bcond_without intree_cares
%endif

%if 0%{?suse_version} >= 1200
%bcond_with    intree_icu
%else
%bcond_without intree_icu
%endif

%if 0
%bcond_with    intree_nghttp2
%else
%bcond_without intree_nghttp2
%endif

%ifarch aarch64 ppc ppc64 ppc64le s390 s390x
%bcond_with    gdb
%else
%bcond_without gdb
%endif

# No binutils_gold on SLE 12 GA (aarch64).
%ifarch aarch64
%if 0%{?sle_version} >= 120100 || 0%{?is_opensuse}
%bcond_without binutils_gold
%else
%bcond_with    binutils_gold
%endif
%endif # aarch64

# No binutils_gold on all versions of SLE 12 and Leap 42 (s390x).
%ifarch s390x
%if 0%{?suse_version} > 1320
%bcond_without binutils_gold
%else
%bcond_with    binutils_gold
%endif
%endif # s390x

%ifarch s390
%bcond_with    binutils_gold
%endif

%ifnarch aarch64 s390x s390
%bcond_without binutils_gold
%endif

Summary:        Evented I/O for V8 JavaScript
License:        MIT
Group:          Development/Languages/NodeJS
Url:            https://nodejs.org
Source:         https://nodejs.org/dist/v%{version}/node-v%{version}.tar.xz
Source1:        https://nodejs.org/dist/v%{version}/SHASUMS256.txt
Source2:        https://nodejs.org/dist/v%{version}/SHASUMS256.txt.sig
Source3:        nodejs.keyring

## Patches not distribution specific
Patch1:         8334.diff
Patch3:         fix_ci_tests.patch
Patch4:         fix_ci_ssl_tests.patch
Patch6:         icu_61_namespacefix.patch

Patch20:        CVE-2018-12115.patch
Patch21:        openssl_1_0_2p.patch

## Patches specific to SUSE and openSUSE
# PATCH-FIX-OPENSUSE -- set correct path for dtrace if it is built
Patch101:       nodejs-libpath.patch
# PATCH-FIX-UPSTREAM -- use custom addon.gypi by default instead of
# downloading node source
Patch102:       node-gyp-addon-gypi.patch
# PATCH-FIX-SLE -- configure script uses Python check_output method
# which isn't included in Python 2.6 (used in SLE 11).
Patch103:       nodejs-sle11-python26-check_output.patch
# PATCH-FIX-OPENSUSE -- install user global npm packages to /usr/local
# instead of /usr
Patch104:       npm_search_paths.patch

# Use versioned binaries and paths
Patch200:       versioned.patch

Patch201:       env_shebang.patch

%if %{with binutils_gold}
BuildRequires:  binutils-gold
%endif

# Node.js 4/6/7 requires GCC 4.8.5+.
#
# For Node.js 8.x, upstream requires GCC 4.9.4+, as GCC 4.8 may have
# slightly buggy C++11 support: https://github.com/nodejs/node/pull/13466
#
# If the default compiler is not supported, use the most recent compiler
# version available.
%if 0%{?suse_version} == 1110
# GCC 5 is only available in the SUSE:SLE-11:SP4:Update repository (SDK).
%if %node_version_number >= 8
BuildRequires:   gcc5-c++
%define cc_exec  gcc-5
%define cpp_exec g++-5
%else
BuildRequires:   gcc48-c++
%define cc_exec  gcc-4.8
%define cpp_exec g++-4.8
%endif # node >= 8
%endif # sles == 11

# Use GCC 7, since it is in SLE-12:Update
%if %node_version_number >= 8 && 0%{?suse_version} == 1315
BuildRequires:   gcc7-c++
%define cc_exec  gcc-7
%define cpp_exec g++-7
%endif # node >= 8 and sle == 12

# No special version defined, use default.
%if ! 0%{?cc_exec:1}
BuildRequires:  gcc-c++
%endif

BuildRequires:  fdupes
BuildRequires:  pkg-config
BuildRequires:  procps
BuildRequires:  xz
BuildRequires:  zlib-devel
%if 0%{?suse_version} >= 1500
BuildRequires:  python2
%else
BuildRequires:  python
%endif

%if ! %{with intree_openssl}

%if %node_version_number >= 8
BuildRequires:  openssl-devel >= %{openssl_req_ver}
%else # older node doesn't support OpenSSL 1.1

%if 0%{?suse_version} >= 1330
BuildRequires:  libopenssl-1_0_0-devel
%else
BuildRequires:  openssl-devel >= %{openssl_req_ver}
%endif

%endif # older node doesn't support OpenSSL 1.1
%endif # ! {with intree_openssl}

%if ! %{with intree_cares}
BuildRequires:  pkgconfig(libcares) >= 1.10.0
%endif

%if ! %{with intree_icu}
BuildRequires:  pkgconfig(icu-i18n) >= 52
%endif

%if ! %{with intree_nghttp2}
BuildRequires: libnghttp2-devel >= 1.31.0
%endif

Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     npm4

#we need ABI virtual provides where SONAMEs aren't enough/not present so deps
#break when binary compatibility is broken
%global nodejs_abi 4.0
Provides:       nodejs(abi) = %{nodejs_abi}

#this corresponds to the "engine" requirement in package.json
Provides:       nodejs(engine) = %{version}

# Multiple versions of NodeJS can be installed at a time, but
# to properly allow correct version execution from 3rd party
# npm software, `env node` requires further help than only
# update-alternatives can provide.
Provides:       nodejs = %{version}
Requires:       nodejs-common

# For SLE11, to be able to use the certificate store we need to have properly
# symlinked certificates. The compatability symlinks are provided by the
# openssl1 library in the Security Module
%if 0%{?suse_version} == 1110
Requires:       openssl1
%endif

# Building Node.js only makes sense on V8 architectures.
ExclusiveArch:  %{ix86} x86_64 armv7hl aarch64 ppc ppc64 ppc64le
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Node.js is a JavaScript runtime built on Chrome's V8 JavaScript engine. Node.js
uses an event-driven, non-blocking I/O model. Node.js has a package ecosystem
provided by npm.

%package devel
Summary:        Files needed for development of NodeJS platforms
Group:          Development/Languages/NodeJS
Provides:       nodejs-devel = %{version}
Requires:       %{name} = %{version}

%description devel
This package provides development headers for Node.js.

%package -n npm4
Summary:        Package manager for Node.js
Group:          Development/Languages/NodeJS
Requires:       %{name}-devel = %{version}
Provides:       nodejs-npm = %{version}
Obsoletes:      nodejs-npm < 4.0.0
Provides:       npm(npm) = 2.15.11
Provides:       npm = %{version}
%if 0%{?suse_version} >= 1500
Recommends:     python2
%else
Recommends:     python
%endif

%description -n npm4
A package manager for Node.js that allows developers to install and
publish packages to a package registry.

%package docs
Summary:        Node.js API documentation
Group:          Documentation/Other
%if 0%{?suse_version} >= 1200
# using noarch subpackage seems to break debuginfo on older releases
BuildArch:      noarch
%endif

%description docs
The API documentation for the Node.js JavaScript runtime.

%prep
echo "`grep node-v%{version}.tar.xz %{S:1} | head -n1 | cut -c1-64`  %{S:0}" | sha256sum -c
%setup -q -n node-v%{version}
%patch1 -p1
%patch3 -p1
%if ! %{with intree_openssl}
%patch4 -p1
%endif
%patch6 -p1
%patch20 -p1
%patch21 -p1
%patch101 -p1
%patch102 -p1
# Add check_output to configure script (not part of Python 2.6 in SLE11).
%if 0%{?suse_version} == 1110
%patch103 -p1
%endif
%patch104 -p1
%patch200 -p1
%patch201 -p1

# abnormalities from patching
find -name configure.js.orig -delete

%build
# Make sure nothing gets included from bundled deps:
# We only delete the source and header files, because
# the remaining build scripts are still used.
%if ! %{with intree_openssl}
find deps/openssl -name *.[ch] -delete
%endif

%if ! %{with intree_icu}
rm -rf deps/icu-small
%endif

%if ! %{with intree_cares}
find deps/cares -name *.[ch] -delete
%endif

find deps/zlib -name *.[ch] -delete

# Annoying, over-repetitive patch updated just because lines in
# documentation changes every version.
find -name *.md.orig -delete

# percent-configure pulls in something that confuses node's configure
# script, so we'll do it thus:
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"

%if 0%{?cc_exec:1}
export CC=%{?cc_exec}
export CXX=%{?cpp_exec}
%endif

# Node.js 4.x does not include the ICU database in the source tarball.
%define has_small_icu %(test -d "deps/icu-small" && echo 1 || echo 0)

./configure \
    --prefix=%{_prefix} \
%if ! %{with intree_openssl}
    --shared-openssl \
%endif
    --shared-zlib \
%if ! %{with intree_cares}
    --shared-cares \
%endif
%if ! %{with intree_icu}
    --with-intl=system-icu \
%else
%if %{has_small_icu}
    --with-intl=small-icu \
    --with-icu-source=deps/icu-small \
%endif
%endif
%if ! %{with intree_nghttp2}
    --shared-nghttp2 \
%endif
%if %{with gdb}
    --gdb \
%endif
    --without-dtrace \
    --openssl-use-def-ca-store

make %{?_smp_mflags}

# Fix documentation permissions
find doc/api -type f -exec chmod 0644 {} +

%install
%make_install %{?_smp_mflags}
rm %{buildroot}%{_datadir}/doc/node/gdbinit
rm -f %{buildroot}%{_datadir}/doc/node/lldbinit
rm -f %{buildroot}%{_datadir}/doc/node/lldb_commands.py

# remove .bak files, if any
find %{buildroot} -name \*.bak -print -delete

# npm/npx man page
install -D -m 644 deps/npm/man/man1/npm.1 %{buildroot}%{_mandir}/man1/npm%{node_version_number}.1
%if %{node_version_number} >= 8
install -D -m 644 deps/npm/man/man1/npx.1 %{buildroot}%{_mandir}/man1/npx%{node_version_number}.1
%endif

#node-gyp needs common.gypi too
install -D -m 644 common.gypi \
	%{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules/node-gyp/common.gypi
#       %%{buildroot}%%{_datadir}/node/common.gypi
# install addon-rpm.gypi
install -D -m 644 addon-rpm.gypi \
       %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules/node-gyp/addon-rpm.gypi

# clean
# hidden files and directories
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number} -name ".*" -print0 | xargs -r0 -0 rm -rf --
# windows stuff
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number} -name "*.bat" -delete
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number} -name "*.cmd" -delete
# build stuff
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number} -name "Makefile" -delete
rm -rf %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/{test,scripts}
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules -name "*.sh" -delete
rm -rf %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules/node-gyp/src
# remove examples/tests/benchmark stuff
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules -name "example*" -print0 | xargs -0 rm -rf --
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/NODE_MODULES -name "test*" -print0 | xargs -0 rm -rf --
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules -name "*_test.*" -delete
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules -type d -name "benchmark" -print0 | xargs -0 rm -rf --

# fix permissions
find %{buildroot}%{_libdir}/node_modules -type f -exec chmod 0644 {} +
chmod 0755 %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/bin/np*-cli.js
chmod 0755 %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/bin/node-gyp-bin/node-gyp
chmod 0755 %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules/node-gyp/bin/node-gyp.js
%if %{node_version_number} >= 8
chmod 0755 %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules/npm-lifecycle/node-gyp-bin/node-gyp
%endif

# browser.js is useless for npm cli
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number} -name "browser.js" -delete

# file duplicates
%fdupes %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}
%fdupes %{buildroot}%{_includedir}/node%{node_version_number}

# Update alternatives
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
ln -s -f node-default     %{buildroot}%{_sysconfdir}/alternatives/node-default
ln -s -f node.1%{ext_man} %{buildroot}%{_sysconfdir}/alternatives/node.1%{ext_man}
ln -s -f npm-default      %{buildroot}%{_sysconfdir}/alternatives/npm-default
ln -s -f npm.1%{ext_man}  %{buildroot}%{_sysconfdir}/alternatives/npm.1%{ext_man}
ln -s %{_sysconfdir}/alternatives/node-default         %{buildroot}%{_bindir}/node-default
ln -s %{_sysconfdir}/alternatives/node.1%{ext_man}     %{buildroot}%{_mandir}/man1/node.1%{ext_man}
ln -s %{_sysconfdir}/alternatives/npm-default          %{buildroot}%{_bindir}/npm-default
ln -s %{_sysconfdir}/alternatives/npm.1%{ext_man}      %{buildroot}%{_mandir}/man1/npm.1%{ext_man}
%if %{node_version_number} >= 8
ln -s -f npx-default      %{buildroot}%{_sysconfdir}/alternatives/npx-default
ln -s -f npx.1%{ext_man}  %{buildroot}%{_sysconfdir}/alternatives/npx.1%{ext_man}
ln -s %{_sysconfdir}/alternatives/npx-default          %{buildroot}%{_bindir}/npx-default
ln -s %{_sysconfdir}/alternatives/npx.1%{ext_man}      %{buildroot}%{_mandir}/man1/npx.1%{ext_man}
%endif

# We need to own license directory on old versions of SLE
%if 0%{?suse_version} < 1500
mkdir -p %{buildroot}%{_defaultlicensedir}
%endif

%check
ln addon-rpm.gypi deps/npm/node_modules/node-gyp/addon-rpm.gypi
# Tarball doesn't have eslint package distributed, so disable some tests
find test -name \*-eslint-\* -print -delete
# No documentation is generated, don't bother checking it
rm -f test/doctool/test-make-doc.js
# DNS lookup doesn't work in build root
rm -f test/parallel/test-dns-cancel-reverse-lookup.js \
      test/parallel/test-dns-resolveany.js
# multicast test fail since no socket?
rm -f test/parallel/test-dgram-membership.js
# Run CI tests - 'advisory for now'
make test-ci || echo "****** UNIT TESTS NOT ALL HAPPY *****"

%files
%defattr(-, root, root)
%license LICENSE
%doc AUTHORS *.md
%doc deps/v8/tools/gdbinit
%dir %{_libdir}/node_modules
%{_bindir}/node%{node_version_number}
%{_mandir}/man1/node%{node_version_number}.1%{ext_man}
%ghost %{_bindir}/node-default
%ghost %{_mandir}/man1/node.1%{ext_man}
%ghost %{_sysconfdir}/alternatives/node-default
%ghost %{_sysconfdir}/alternatives/node.1%{ext_man}
%exclude %{_libdir}/node_modules/npm%{node_version_number}
# We need to own directory on old versions of SLE
%if 0%{?suse_version} < 1500
%dir %{_defaultlicensedir}
%endif

%files -n npm%{node_version_number}
%defattr(-, root, root)
%{_bindir}/npm%{node_version_number}
%{_libdir}/node_modules/npm%{node_version_number}
%{_mandir}/man1/npm%{node_version_number}.1%{ext_man}
%ghost %{_bindir}/npm-default
%ghost %{_mandir}/man1/npm.1%{ext_man}
%ghost %{_sysconfdir}/alternatives/npm-default
%ghost %{_sysconfdir}/alternatives/npm.1%{ext_man}

%if %{node_version_number} >= 8
%{_bindir}/npx%{node_version_number}
%{_mandir}/man1/npx%{node_version_number}.1%{ext_man}
%ghost %{_bindir}/npx-default
%ghost %{_mandir}/man1/npx.1%{ext_man}
%ghost %{_sysconfdir}/alternatives/npx-default
%ghost %{_sysconfdir}/alternatives/npx.1%{ext_man}
%endif

%files devel
%defattr(-, root, root)
%{_includedir}/node%{node_version_number}
%dir %{_datadir}/systemtap
%dir %{_datadir}/systemtap/tapset
%{_datadir}/systemtap/tapset/node%{node_version_number}.stp

%files docs
%defattr(-,root,root)
%doc doc/api

%pre
# remove files that are no longer owned but provided by update-alternatives
if ! [ -L %{_mandir}/man1/node.1%{ext_man} ]; then
    rm -f %{_mandir}/man1/node.1%{ext_man}
fi

%post
update-alternatives \
        --install %{_bindir}/node-default node-default %{_bindir}/node%{node_version_number} %{node_version_number} \
        --slave %{_mandir}/man1/node.1%{ext_man} node.1%{ext_man} %{_mandir}/man1/node%{node_version_number}.1%{ext_man}

%postun
if [ ! -f %{_bindir}/node%{node_version_number} ] ; then
    update-alternatives --remove node-default %{_bindir}/node%{node_version_number}
fi

%pre -n npm%{node_version_number}
# remove files that are no longer owned but provided by update-alternatives
if ! [ -L %{_mandir}/man1/npm.1%{ext_man} ]; then
    rm -f %{_mandir}/man1/npm.1%{ext_man}
fi

%post -n npm%{node_version_number}
update-alternatives \
        --install %{_bindir}/npm-default npm-default %{_bindir}/npm%{node_version_number} %{node_version_number} \
        --slave %{_mandir}/man1/npm.1%{ext_man} npm.1%{ext_man} %{_mandir}/man1/npm%{node_version_number}.1%{ext_man}
%if %{node_version_number} >= 8
update-alternatives \
        --install %{_bindir}/npx-default npx-default %{_bindir}/npx%{node_version_number} %{node_version_number} \
        --slave %{_mandir}/man1/npx.1%{ext_man} npx.1%{ext_man} %{_mandir}/man1/npx%{node_version_number}.1%{ext_man}
%endif

%postun -n npm%{node_version_number}
if [ ! -f %{_bindir}/npm%{node_version_number} ] ; then
    update-alternatives --remove npm-default %{_bindir}/npm%{node_version_number}
fi
%if %{node_version_number} >= 8
if [ ! -f %{_bindir}/npx%{node_version_number} ] ; then
    update-alternatives --remove npx-default %{_bindir}/npx%{node_version_number}
fi
%endif

%changelog
* Thu Aug 23 2018 adam.majer@suse.de
- CVE-2018-12115.patch: buffer: avoid overrun on UCS-2 string write
  (CVE-2018-12115, bsc#1105019)
- openssl_1_0_2p.patch: deps: Upgrade to OpenSSL 1.0.2p, fixing:
  * Client DoS due to large DH parameter (CVE-2018-0732, bsc#1097158)
  * ECDSA key extraction via local side-channel
* Sun Jul 29 2018 jengelh@inai.de
- Ensure neutrality of description.
- Use %%make_install.
* Fri Jun 15 2018 adam.majer@suse.de
- Recommend same major version npm package (bsc#1097748)
* Thu May 24 2018 adam.majer@suse.de
- env_shebang.patch: use absolute paths in executable shebang lines
- versioned.patch: updated to move shebang modifications to above
  patch.
* Fri May 11 2018 adam.majer@suse.de
- icu_61_namespacefix.patch: Fix building with ICU61.1 (bsc#1091764)
* Thu Apr  5 2018 adam.majer@suse.de
- Install license with %%license, not %%doc (bsc#1082318)
* Wed Apr  4 2018 adam.majer@suse.de
- Fix some node-gyp permissions
* Tue Apr  3 2018 adam.majer@suse.de
- New upstream maintenance 4.9.1:
  * Security fixes:
    + Fix for 'path' module regular expression denial of service
    (bsc#1087459, CVE-2018-7158)
    + Reject spaces in HTTP Content-Length header values
    (bsc#1087453, CVE-2018-7159)
  * Upgrade to OpenSSL 1.0.2o
  * deps: reject interior blanks in Content-Length
  * deps: upgrade http-parser to v2.8.0
- fix_ci_tests.patch: refreshed
* Thu Mar 22 2018 adam.majer@suse.de
- remove any old manpage files in %%pre from before update-alternatives
  were used to manage symlinks to these manpages.
* Tue Feb 13 2018 adam.majer@suse.de
- Add Recommends and BuildRequire on python2 for npm. node-gyp
  requires this old version of python for now. This is only needed
  for binary modules.
* Tue Jan 30 2018 ro@suse.de
- even on recent codestreams there is no binutils gold on s390
  only on s390x
* Thu Dec 21 2017 adam.majer@suse.de
- Enable CI tests in %%check target
  + fix_ci_ssl_tests.patch: Disable testing of obsolete curves
    which are not enabled OpenSUSE's OpenSSL library
  + fix_ci_tests.patch:
  - DNS queries in buildroots are failing with EAI_AGAIN
  - disable test-module-loading-globalpaths.js - we have
    hardcoded global paths
  + versioned.patch: call versioned node binary for tests
* Sat Dec  9 2017 qantas94heavy@gmail.com
- New upstream maintenance release 4.8.7:
  * deps/openssl: updated to 1.0.2n (only applies to SLE 12 SP1
    and lower) (bsc#1072322)
    [ CVE-2017-3738 CVE-2017-15896 ]
- Remove unnecessary curl BuildRequires
* Wed Nov 29 2017 qantas94heavy@gmail.com
- Change BuildRequires from openssl-devel to libopenssl-1_0_0-devel
  due to Tumbleweed/Leap 15 change to OpenSSL 1.1.0 as default
* Thu Nov 16 2017 adam.majer@suse.de
- Update nodejs.keyring based on current Release Team as found on
  https://github.com/nodejs/node#release-team
* Mon Nov 13 2017 adam.majer@suse.de
- Fix permissions of node-gyp. This should be executable to allow
  building of binary node modules.
* Mon Nov 13 2017 adam.majer@suse.de
- New upstream maintenance release 4.8.6:
  * crypto: upgrade openssl sources to 1.0.2m
    [OpenSSL Security Advisory (bsc#1066242, bsc#1056058)
    CVE-2017-3735 CVE-2017-3736]
  * deps: add support for more modern versions of INTL
- 0f3e69db.patch: removed, upstreamed
- icu59.patch: removed, upstreamed
* Wed Oct 25 2017 qantas94heavy@gmail.com
- New upstream maintenance release 4.8.5:
  * zlib: (CVE-2017-14919: only affects TW) In zlib v1.2.9, a
    change was made that causes an exception to be thrown when a
    raw deflate stream is initialized with windowBits set to 8.
    Node.js will now gracefully set windowBits to 9 (replicating
    the legacy behavior) to avoid a DOS vector.
* Thu Oct 19 2017 adam.majer@suse.de
- Replace {{node_version_major}} with RPM define %%node_version_number
  for simpler spec file review.
- Make sure npm program remains executable
* Wed Aug  2 2017 adam.majer@suse.de
- Fix update-alternative handling in %%postun - don't remove
  links on upgrades.
* Wed Jul 12 2017 adam.majer@suse.de
- New LTS upstream version 4.8.4
  * v8: disable V8 snapshots. The hashseed embedded in the snapshot
    is currently the same for all runs of the binary. This opens
    node up to collision attacks which could result in a Denial
    of Service. We have temporarily disabled snapshots until a more
    robust solution is found (bnc#1048299, CVE-2017-11499).
  * http: fixes http.get with numeric authorization options that
    created/used uninitialized buffers as the authentication string
  * The c-ares function ares_parse_naptr_reply(), which is used for
    parsing NAPTR responses, could be triggered to read memory
    outside of the given input buffer if the passed in DNS response
    packet was crafted in a particular way.
    (CVE-2017-1000381, bnc#1044946)
* Fri Jul  7 2017 adam.majer@suse.de
- Depend on nodejs-common that is then used to pick correctly
  versioned node or npm binary. This is required since 3rd party
  modules use `/usr/bin/env node` which breaks if multiple versions
  of NodeJS are installed at the same time and non-default version
  is used (for example, to compile a native module)
* Thu Jul  6 2017 adam.majer@suse.de
- npm_search_paths.patch: Since concurrent installations are now
  possible, node manual pages are moved once again back under npm
  searcheable locations only.
- versioned.patch: All files are now under versioned directoies
  and names. node and npm symlinks are now managed by
  update-alternatives
- node-gyp-addon-gypi.patch: Reference versioned directories only
* Tue Jun 13 2017 adam.majer@suse.de
- Fix typo in node-gyp-addon-gypi.patch patch
* Tue May 30 2017 adam.majer@suse.de
- 0f3e69db.patch, icu59.patch: GCC 7 compilation fixes for v8
  backported and add missing ICU59 headers (bnc#1041283)
* Tue May 23 2017 adam.majer@suse.de
- New upstream LTS release 4.8.3
  * v8: trigger OOM crash if memory allocation fails
  * src: fix base64 decoding in rare edgecase
  * tls:
    + fix segfault on destroy after partial read
    + keep track of stream that is closed
    + TLSSocket emits 'error' on handshake failure
- nodejs-libpath.patch: updated
* Wed Apr  5 2017 qantas94heavy@gmail.com
- New upstream maintenance release 4.8.2
  * crypto: fix memory leak if certificate is revoked (#12089)
- Changes not applicable to openSUSE in 4.8.2:
  * deps: upgrade zlib to 1.2.11 (#10980)
- Changes in LTS release 4.8.1
  * buffer: The performance of .toJSON() is now up to 2859%% faster
    on average.
  * IPC: Batched writes have been enabled for process IPC on
    platforms that support Unix Domain Sockets. Performance gains
    may be up to 40%% for some workloads.
  * http: Control characters are now always rejected when using
    http.request().
  * node: Heap statistics now support values larger than 4GB.
- Modify 8334.diff:
  * Bring patch in line with upstream changes (#8334)
* Sun Feb 26 2017 qantas94heavy@gmail.com
- New upstream LTS release 4.8.0
  * child_process: add shell option to spawn()
  * crypto: add ALPN Support
  * crypto: allow adding extra certs to well-known CAs
  * deps/v8: expose statistics about heap spaces
  * fs: add the fs.mkdtemp() function
  * process: add process.memoryUsage().external
  * process: add process.cpuUsage()
- Modify 8334.diff:
  * Remove merged reference counting code (#9409)
* Fri Feb  3 2017 adam.majer@suse.de
- New upstream LTS release 4.7.3
  * deps: upgrade openssl sources to 1.0.2k
    (CVE-2017-3731, CVE-2017-3732, CVE-2016-7055,
    bnc#1022085, bnc#1022086, bnc#1009528)
- No changes in LTS version 4.7.2
- Adjusted 8334.diff to be inline with accepted changes
- Merge nodejs4.changes from SLE and devel project
* Fri Jan  6 2017 qantas94heavy@gmail.com
- Add basic check that Node.js loads successfully to spec file
* Wed Jan  4 2017 qantas94heavy@gmail.com
- New upstream LTS release 4.7.1
  * build: shared library support is now working for AIX builds
  * repl: passing options to the repl will no longer overwrite
    defaults
  * timers: recanceling a cancelled timers will no longer throw
* Fri Dec  9 2016 qantas94heavy@gmail.com
- New upstream LTS version 4.7.0
  * build: introduce the configure --shared option for embedders
  * debugger: make listen address configurable in debugger server
  * dgram: generalized send queue to handle close, fixing a
    potential throw when dgram socket is closed in the
    listening event handler
  * http: introduce the 451 status code "Unavailable For
    Legal Reasons"
  * gtest: the test reporter now outputs tap comments as yamlish
  * tls: introduce secureContext for tls.connect (useful for
    caching client certificates, key, and CA certificates)
  * tls: fix memory leak when writing data to TLSWrap instance
    during handshake
  * src: node no longer aborts when c-ares initialization fails
- Modify 8334.diff:
  * ported and updated system CA store for the new node crypto code
- Refresh nodejs-libpath.patch
* Thu Dec  1 2016 qantas94heavy@gmail.com
- New upstream LTS version 4.6.2
  * build:
    + It is now possible to build the documentation from the release tarball.
  * buffer:
    + Buffer.alloc() will no longer incorrectly return a zero filled buffer
    when an encoding is passed.
  * deps:
    + Upgrade npm in LTS to 2.15.11.
  * repl:
    + Enable tab completion for global properties.
  * url:
    + url.format() will now encode all "#" in search.
* Wed Nov 23 2016 adam.majer@suse.de
- Add missing conflicts to base package. It's not possible to have
  concurrent nodejs installations.
* Fri Nov 18 2016 adam.majer@suse.de
- Package unification across various branches of NodeJS. Package
  for 4.x, 6.x and current (7.x) branches of NodeJS are now
  handled via GitHub repository.
- remove support-arm64-build.patch: no longer required
- remove nodejs-libpath64.patch: obsolete
* Tue Nov  8 2016 adam.majer@suse.de
- npm4 should provide versioned nodejs-npm and npm allowing
  nodejs-packaging to continue to function properly in Leap 42.2
  (bnc #1009011)
* Wed Oct 19 2016 qantas94heavy@gmail.com
- New upstream LTS version 4.6.1
  * c-ares: fix for single-byte buffer overwrite, CVE-2016-5180
    more information at https://c-ares.haxx.se/adv_20160929.html
    (bnc #1007728)
* Tue Oct  4 2016 adam.majer@suse.de
- npm4 now provides nodejs-npm to ease upgrades for Leap
* Thu Sep 29 2016 adam.majer@suse.de
- enable usage of system certificate store on SLE11SP4 by
  requiring openssl1 (boo#1000036)
- nodejs-libpath.patch:
  * adapt patch from main nodejs project so it builds on SLE11
- New upstream LTS version 4.6.0
  * openssl update (not applicable for SLE12SP2, Leap 42.2 and later)
    + upgrade to 1.0.2j (CVE-2016-6304, CVE-2016-2183, CVE-2016-2178,
    CVE-2016-6306, CVE-2016-7052)
    + remove support for dynamic 3rd party engine modules
  * http: Properly validate for allowable characters in input
    user data. This introduces a new case where throw may occur
    when configuring HTTP responses, users should already
    be adopting try/catch here. (CVE-2016-5325, bnc#985201)
  * tls: properly validate wildcard certificates
    (CVE-2016-7099, bnc#1001652)
  * buffer: Zero-fill excess bytes in new Buffer objects created
    with Buffer.concat()
* Fri Aug 26 2016 adam.majer@suse.de
- New upstream LTS version 4.5.0 (bnc#997405)
  * buffer:
    + backport new buffer constructor APIs to v4.x
    + backport --zero-fill-buffers cli option
    + ignore negative allocation lengths
  * build
    + add Intel Vtune profiling support
  * repl
    + copying tabs shouldn't trigger completion
  * src
    + add node::FreeEnvironment public API
  * test
    + run v8 tests from node tree
  * V8
    + Add post mortem data to improve object inspection and
    function's context variables inspection
  * upgrade libuv to 1.9.1
  * upgrade npm to 2.15.9
- 8334.diff
  * use system CA store instead of one provided by Node
- Refresh patches
* Wed Aug 10 2016 adam.majer@suse.de
- use system OpenSSL with Leap 42.2 and SLE12:SP2
- simplify source code integrity check
  + use GPG service instead of explicit BR
  + add empty checksum so GPG service is run - it's not detached signature
    like it thinks it is.
* Mon Jul  4 2016 adam.majer@suse.de
- rename patches to have a .patch suffix, for consistancy
- npm_search_paths.patch:
  Change defaultPrefix to /usr/local if it is detected to be
  /usr. This is in attempt to prevent globally installed npm-managed
  packages from installing into the zypper managed prefix.
- refreshed patches support-arm64-build.patch
- use upstream .xz instead of .gz tarball
* Fri Jul  1 2016 adam.majer@suse.de
- New upstream version 4.4.7
  * debugger:
    + All properties of an array (aside from length) can now be printed
    in the repl
  * Upgrade npm to 2.15.8 (Rebecca Turner)
  * Fix for a bug that became more prevalent with the stream changes
    that landed in v4.4.5. (Anna Henningsen). 'reset awaitDrain after manual
    .resume()'
  * V8:
    + Fix for a bug in crankshaft that was causing crashes on arm64
    (Myles Borins)
    +  Add missing classes to postmortem info such as JSMap and JSSet
    (evan.lucas)
- Add upstream release keyring
- Verify upstream sources during %%prep
* Mon Jun 27 2016 adam.majer@suse.de
- Use build flags to enable/disable gdb usage instead of
  configure script. Easier to find and change in future.
- Fix paths, and have to fix lots of paths because they
  are all more or less hardcoded relative paths.
- Renumber patches allowing upstream patches to be inserted
  before our own.
* Fri Jun 24 2016 adam.majer@suse.de
- New upstream version 4.4.6
  + fix buffer overflow vulnerability discovered in v8
  (CVE-2016-1669)
* Thu Jun 16 2016 adam.majer@suse.de
- Change detection of library paths from runtime to compile time.
  nodejs-libpath.patch, nodejs-libpath64.patch
* Wed Jun 15 2016 adam.majer@suse.de
- This package is in response to FATE#320396 and ECO#317945
  and references bnc#958943
  It's to be part of Web and Scripting Module
- Use build conditional for intree_openssl
- Fix permissions of some supplies javascript files - they are
  not executables
- General cleanup of the package
* Wed Jun 15 2016 adam.majer@suse.de
- Tighten dependencies so we don't end up with mixed versions
  installed.
* Tue Jun 14 2016 adam.majer@suse.de
- Dedup manpages
- Conflict with other providers of NodeJS packages. This is
  important if we want to provide NodeJS v6.x branch along with
  v4.x branch
* Mon Jun  6 2016 adam.majer@suse.de
- 'New' package of 4.x LTS branch of NodeJS, based on v6.2.1
  from Tumbleweed
-  Fix search paths to actually look where modules are installed
